@@ -36,13 +36,12 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'openstack'
-copyright = u'2017, OpenStack Developers'
+project = 'monasca-tempest-plugin'
+copyright = '2017, OpenStack Developers'
 
 # openstackdocstheme options
-repository_name = 'openstack/openstack'
-bug_project = 'monasca_tempest_plugin'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/monasca-tempest-plugin'
+openstackdocs_use_storyboard = True
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -52,7 +51,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
